@@ -1,6 +1,6 @@
 #!/bin/sh
 #$Id$
-#Copyright (c) 2014-2016 Pierre Pronchery <khorben@defora.org>
+#Copyright (c) 2014-2025 Pierre Pronchery <khorben@defora.org>
 #This file is part of DeforaOS Artwork
 #Redistribution and use in source and binary forms, with or without
 #modification, are permitted provided that the following conditions are met:
@@ -27,7 +27,7 @@
 #variables
 BGCOLOR="black"
 FGCOLOR="white"
-FONT="FontAwesome"
+FONT="Font Awesome 5 Free"
 ICONS="
 		actions/application-exit
 		actions/appointment-new
@@ -165,6 +165,7 @@ ICONS="
 		status/network-transmit-receive
 		status/network-offline"
 PREFIX="/usr/local"
+IMGEXT=".png"
 PROGNAME="convert.sh"
 SYMLINKS="
 accessories-calculator	apps/calc
@@ -494,13 +495,17 @@ zoom-original		actions/viewmag1
 zoom-out		actions/gtk-zoom-out
 zoom-out		actions/stock_zoom-out
 zoom-out		actions/viewmag-"
+THEMEEXT=".theme"
 [ -f "../config.sh" ] && . "../config.sh"
 #executables
-CONVERT="convert -quiet"
+CONVERT="convert"
 DEBUG="_debug"
 FIND="find"
+GM="gm"
+GMORIM="_gmorim"
 INSTALL="install -m 0644"
 LN="ln -f"
+MAGICK="magick"
 MKDIR="mkdir -m 0755 -p"
 RM="rm -f"
 SORT="sort"
@@ -516,10 +521,10 @@ _convert()
 	shift 2
 
 	$DEBUG $MKDIR -- "$OBJDIR$folder/places"		|| return 2
-	$DEBUG $CONVERT -background none -density 300 \
+	$GMORIM $CONVERT -background none -density 300 \
 		"../data/DeforaOS-d-${BGCOLOR}.svg" \
 		-resize "$size" $@ \
-		"$OBJDIR$folder/places/start-here.png"		|| return 2
+		"$OBJDIR$folder/places/start-here$IMGEXT"	|| return 2
 
 	#icons
 	echo "$ICONS" | while read char stock; do
@@ -540,9 +545,9 @@ _convert()
 		gravity Center
 		text 0,0 '$char'
 	pop graphic-context
-pop graphic-context" | $DEBUG $CONVERT -background none - \
+pop graphic-context" | $GMORIM $CONVERT -background none mvg:- \
 		-resize "$size" $@ \
-		"$OBJDIR$folder/${stock}.png"			|| return 2
+		"$OBJDIR$folder/${stock}$IMGEXT"		|| return 2
 	done
 	[ $? -eq 0 ]						|| return 2
 
@@ -550,7 +555,7 @@ pop graphic-context" | $DEBUG $CONVERT -background none - \
 	echo "$SYMLINKS" | while read from to; do
 		[ -z "$from" ] && continue
 
-		$DEBUG $LN -s -- "${from}.png" "$OBJDIR$folder/${to}.png" \
+		$DEBUG $LN -s -- "${from}$IMGEXT" "$OBJDIR$folder/${to}$IMGEXT" \
 								|| return 2
 	done
 	[ $? -eq 0 ]						|| return 2
@@ -564,13 +569,13 @@ _clean()
 	size="${2}x${2}"
 	folder="$theme/$size"
 
-	$DEBUG $RM -- "$OBJDIR$folder/places/start-here.png"	|| return 2
+	$DEBUG $RM -- "$OBJDIR$folder/places/start-here$IMGEXT"	|| return 2
 
 	#icons
 	echo "$ICONS" | while read char stock; do
 		[ -z "$char" ] && continue
 
-		$DEBUG $RM -- "$OBJDIR$theme/${size}/${stock}.png" \
+		$DEBUG $RM -- "$OBJDIR$theme/${size}/${stock}$IMGEXT" \
 								|| return 2
 	done
 
@@ -578,11 +583,25 @@ _clean()
 	echo "$SYMLINKS" | while read from to; do
 		[ -z "$from" ] && continue
 
-		$DEBUG $RM -- "$OBJDIR$theme/${size}/${to}.png"	|| return 2
+		$DEBUG $RM -- "$OBJDIR$theme/${size}/${to}$IMGEXT" \
+								|| return 2
 	done
 }
 
 
+#gmorim
+_gmorim()
+{
+	$DEBUG $MAGICK "$@"
+	ret=$?
+	if [ $ret -eq 127 ]; then
+		$DEBUG $GM "$@"
+		ret=$?
+	fi
+	return $ret
+}
+
+
 #debug
 _debug()
 {
@@ -653,8 +672,8 @@ _install()
 
 		$DEBUG $MKDIR -- "$PREFIX/$instdir/${size}x${size}/$dirname" \
 								|| return 2
-		$DEBUG $INSTALL "$OBJDIR$instdir/${size}x${size}/${stock}.png" \
-			"$PREFIX/$instdir/${size}x${size}/${stock}.png" \
+		$DEBUG $INSTALL "$OBJDIR$instdir/${size}x${size}/${stock}$IMGEXT" \
+			"$PREFIX/$instdir/${size}x${size}/${stock}$IMGEXT" \
 								|| return 2
 	done
 
@@ -662,8 +681,8 @@ _install()
 	echo "$SYMLINKS" | while read from to; do
 		[ -z "$from" ] && continue
 
-		$DEBUG $LN -s -- "${from}.png" \
-			"$PREFIX/$instdir/${size}x${size}/${to}.png" \
+		$DEBUG $LN -s -- "${from}$IMGEXT" \
+			"$PREFIX/$instdir/${size}x${size}/${to}$IMGEXT" \
 								|| return 2
 	done
 }
@@ -683,7 +702,7 @@ _uninstall()
 	echo "$ICONS" | while read char stock; do
 		[ -z "$char" ] && continue
 
-		$DEBUG $RM -- "$PREFIX/$instdir/${size}x${size}/${stock}.png" \
+		$DEBUG $RM -- "$PREFIX/$instdir/${size}x${size}/${stock}$IMGEXT" \
 								|| return 2
 	done
 
@@ -691,7 +710,7 @@ _uninstall()
 	echo "$SYMLINKS" | while read from to; do
 		[ -z "$from" ] && continue
 
-		$DEBUG $RM -- "$PREFIX/$instdir/${size}x${size}/${to}.png" \
+		$DEBUG $RM -- "$PREFIX/$instdir/${size}x${size}/${to}$IMGEXT" \
 								|| return 2
 	done
 }
@@ -750,8 +769,8 @@ while [ $# -gt 0 ]; do
 
 	#clean
 	if [ $clean -ne 0 ]; then
-		if [ "$filename" = "index.theme" ]; then
-			$DEBUG $RM -- "$theme/index.theme"	|| exit 2
+		if [ "$filename" = "index$THEMEEXT" ]; then
+			$DEBUG $RM -- "$theme/index$THEMEEXT"	|| exit 2
 		else
 			_clean "$theme" "$size"			|| exit 2
 		fi
@@ -760,7 +779,7 @@ while [ $# -gt 0 ]; do
 
 	#uninstall
 	if [ $uninstall -eq 1 ]; then
-		if [ "$filename" = "index.theme" ]; then
+		if [ "$filename" = "index$THEMEEXT" ]; then
 			_uninstall "$target"			|| exit 2
 		else
 			_uninstall "$target" "$size"		|| exit 2
@@ -770,7 +789,7 @@ while [ $# -gt 0 ]; do
 
 	#install
 	if [ $install -eq 1 ]; then
-		if [ "$filename" = "index.theme" ]; then
+		if [ "$filename" = "index$THEMEEXT" ]; then
 			_install "$target"			|| exit 2
 		else
 			_install "$target" "$size"		|| exit 2
@@ -779,9 +798,9 @@ while [ $# -gt 0 ]; do
 	fi
 
 	#create
-	if [ "$filename" = "index.theme" ]; then
+	if [ "$filename" = "index$THEMEEXT" ]; then
 		$DEBUG $MKDIR -- "$OBJDIR$theme"		|| exit 2
-		_index "$theme" > "$OBJDIR$theme/index.theme"	|| exit 2
+		_index "$theme" > "$OBJDIR$theme/index$THEMEEXT"|| exit 2
 	else
 		_convert "$theme" "$size"			|| exit 2
 	fi
